Global Module Index — Routes v1.12 documentation

Routes

### Navigation

- index
- modules |
- Routes home |
- Documentation»

# Global Module Index

R

| R |
| `routes` |
| `routes.lru` |
| `routes.mapper` |
| `routes.middleware` |
| `routes.route` |
| `routes.util` |

### Quick search

Enter search terms or a module, class or function name.

### Navigation

- index
- modules |
- Routes home |
- Documentation»

© Copyright 2010, Ben Bangert, Mike Orr. Created using Sphinx 0.6.4.